@@ -6,7 +6,7 @@
  Description: Callback's Arguments VM - Header for MIPS
  License:
 
-   Copyright (c) 2013-2015 Daniel Adler <dadler@uni-goettingen.de>,
+   Copyright (c) 2013-2018 Daniel Adler <dadler@uni-goettingen.de>,
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -31,11 +31,23 @@
 
 struct DCArgs
 {
-  int            ireg_data[8];
-  float          freg_data[8];
-  int            ireg_count;
-  int            freg_count;
-  unsigned char* stackptr;
+	/* Don't change order or types, laid out for asm code to fill in! */
+#if defined(DC__Arch_MIPS) && defined(DC__ABI_MIPS_O32)
+	DCint freg_count;
+#else
+#  define DCARGS_MIPS_NUM_IREGS 8
+#  define DCARGS_MIPS_NUM_FREGS 8
+#  if defined(DC__Arch_MIPS)
+	DCint   ireg_data[DCARGS_MIPS_NUM_IREGS];
+	DCfloat freg_data[DCARGS_MIPS_NUM_FREGS];
+	struct { DCshort i; DCshort f; } reg_count;
+#  elif defined(DC__Arch_MIPS64)
+	DClonglong ireg_data[DCARGS_MIPS_NUM_IREGS];
+	DCdouble   freg_data[DCARGS_MIPS_NUM_FREGS];
+	DClonglong reg_count;
+#  endif
+#endif
+	DCuchar* stackptr;
 };
 
 #endif /* DYNCALLBACK_ARGS_MIPS_H */
