@@ -6,7 +6,7 @@
  Description: 
  License:
 
-   Copyright (c) 2011-2015 Daniel Adler <dadler@uni-goettingen.de>,
+   Copyright (c) 2011-2018 Daniel Adler <dadler@uni-goettingen.de>,
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -66,10 +66,12 @@ int main()
 
   dcTest_initPlatform();
 
-  printf("about to callback...\n");
   cb = dcbNewCallback("ifsdl)s", &cbHandler, &userdata);
+  printf("about to callback (trampoline for 0x%tx at 0x%tx)...\n", &cbHandler, cb);
+
   result = ((short(*)(int, float, short, double, long long))cb)(123, 23.f, 3, 1.82, 9909ull);
   dcbFreeCallback(cb);
+
   printf("successfully returned from callback\n");
   printf("return value (should be 1234): %d\n", result);
 
